function [sigsynt,Cinew,marks,lambdais,count] = wsamod(sig,seuil,nbscales,filter,param,cmin,cmax) 
%   Weakly Self Affine Functions : analysis and synthesis
%
%   Peforms the analysis and synthesis of a 1-D real signal using WSA
%   functions.
%
%   1.  Usage
%
%   [sigsynt,lambdais] = wsamod(sig,[epsilon,NbIter,wavename,waveparam])
%
%   1.1.  Input parameters
%
%   o  sig : Real matrix
%      Contains the original signal
%
%   o  epsilon : Real scalar
%      Specifies the maximal error desied on the Ci's approximation.
%
%   o  NbIter : real positive scalar
%      Number of decomposition Levels to compute
%
%   o  wavename : characters string
%      Wavelet name (Daubechies or Coiflet).
%
%   o  waveparam :
%      Parameter of the chosen wavelet.
%
%   1.2.  Output parameters
%
%   o  sigsynt : Real matrix
%      Contains the synthetic signal
%
%   o  L : Real matrix
%      Containing the lambda_i's. The first two columns contain resp.  the
%      left and the right lambda_i's corresponding to the the first
%      segmented part of the signal and so on.
%
%   2.  See also:
%
%   hist, wave2gifs.
%
%   3.  Example:

% Auhtor Khalid Daoudi, June 1997

% FracLab 2.05 Beta, Copyright  1996 - 2009 by INRIA
% -- --
% For details on use and redistribution refer to $fraclab/licence.txt
%--------------------------------------------------------------------------

N = length(sig) ;
J = floor(log(N)/log(2));
test = 2^J;
if(N > (test + test/2))
	for n=N+1:2*test,
		sig(n) = 0 ;
	end
	N =2*test;
elseif (N>test)
	sig = sig(1:test);
	N = test ;
end
if nargin == 1
	seuil = 10 ;
	nbscales = floor(log(N)/log(2) -1) ;
	filter = 'daubechies' ;
	param = 4 ;
	cmin = 0.1 ;
	cmax = 1;
end
if nargin == 2
	nbscales = log(N)/log(2) -1 ;
	filter = 'daubechies' ;	
	param = 4 ;
	cmin = 0.1 ;
	cmax = 1;
end
if nargin == 3
	filter = 'daubechies' ;	
	param = 4 ;
	cmin = 0.1 ;
	cmax = 1;
end
if nargin == 4
	param = 4 ;
	cmin = 0.1 ;
	cmax = 1;
end
if nargin == 5
	cmin = 0.1 ;
	cmax = 1;
end
if nargin == 6
	cmax = 1;
end

qmf=MakeQMF(filter, param);
[wt,sc_idx,sc_lg] = FWT(sig, nbscales,qmf);
[Ci Ci_idx Ci_lg] = wave2gifs(wt,sc_idx,sc_lg,2,0,2) ;
[Ci_new1,M1,L1] = gifseg(Ci,.501,cmax,seuil) ;
[Ci_new2,M2,L2] = gifseg(Ci_new1,cmin,.5,seuil) ;
[Ci_new3,M3,L3,count] = gifseg(Ci_new2,cmin,cmax,seuil) ;
wt_new = gifs2wave(Ci_new3,wt,sc_idx,sc_lg) ;
sigsynt = IWT(wt_new) ;
lambdais = L3 ;
L = lambda(lambdais);
marks = M3 ;
Cinew = Ci_new3 ;
visures(sig,sigsynt,marks) ;
